@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *  $Revision: 6196 $
+ *  $Revision$
  */
 package org.jajuk.base;
 
@@ -387,20 +387,20 @@ public class Device extends PhysicalItem implements Comparable<Device> {
   public ImageIcon getIconRepresentation() {
     switch ((int) getType()) {
     case 0:
-      return setIcon(IconLoader.getIcon(JajukIcons.DEVICE_DIRECTORY_MOUNTED_SMALL), IconLoader
-          .getIcon(JajukIcons.DEVICE_DIRECTORY_UNMOUNTED_SMALL));
+      return setIcon(IconLoader.getIcon(JajukIcons.DEVICE_DIRECTORY_MOUNTED_SMALL),
+          IconLoader.getIcon(JajukIcons.DEVICE_DIRECTORY_UNMOUNTED_SMALL));
     case 1:
-      return setIcon(IconLoader.getIcon(JajukIcons.DEVICE_CD_MOUNTED_SMALL), IconLoader
-          .getIcon(JajukIcons.DEVICE_CD_UNMOUNTED_SMALL));
+      return setIcon(IconLoader.getIcon(JajukIcons.DEVICE_CD_MOUNTED_SMALL),
+          IconLoader.getIcon(JajukIcons.DEVICE_CD_UNMOUNTED_SMALL));
     case 2:
-      return setIcon(IconLoader.getIcon(JajukIcons.DEVICE_NETWORK_DRIVE_MOUNTED_SMALL), IconLoader
-          .getIcon(JajukIcons.DEVICE_NETWORK_DRIVE_UNMOUNTED_SMALL));
+      return setIcon(IconLoader.getIcon(JajukIcons.DEVICE_NETWORK_DRIVE_MOUNTED_SMALL),
+          IconLoader.getIcon(JajukIcons.DEVICE_NETWORK_DRIVE_UNMOUNTED_SMALL));
     case 3:
-      return setIcon(IconLoader.getIcon(JajukIcons.DEVICE_EXT_DD_MOUNTED_SMALL), IconLoader
-          .getIcon(JajukIcons.DEVICE_EXT_DD_UNMOUNTED_SMALL));
+      return setIcon(IconLoader.getIcon(JajukIcons.DEVICE_EXT_DD_MOUNTED_SMALL),
+          IconLoader.getIcon(JajukIcons.DEVICE_EXT_DD_UNMOUNTED_SMALL));
     case 4:
-      return setIcon(IconLoader.getIcon(JajukIcons.DEVICE_PLAYER_MOUNTED_SMALL), IconLoader
-          .getIcon(JajukIcons.DEVICE_PLAYER_UNMOUNTED_SMALL));
+      return setIcon(IconLoader.getIcon(JajukIcons.DEVICE_PLAYER_MOUNTED_SMALL),
+          IconLoader.getIcon(JajukIcons.DEVICE_PLAYER_UNMOUNTED_SMALL));
     default:
       Log.warn("Unknown type of device detected: " + getType());
       return null;
@@ -519,11 +519,6 @@ public class Device extends PhysicalItem implements Comparable<Device> {
       if (i == OPTION_REFRESH_CANCEL) {
         return;
       }
-      // Check that device is still available
-      boolean readyToMount = checkDevice(true);
-      if (!readyToMount) {
-        return;
-      }
       bAlreadyRefreshing = true;
     } catch (JajukException je) {
       Messages.showErrorMessage(je.getCode());
@@ -604,17 +599,13 @@ public class Device extends PhysicalItem implements Comparable<Device> {
         return choice;
       }
     }
+
+    // JajukException are not trapped, will be thrown to the caller
     final Device device = this;
     if (!device.isMounted()) {
-      try {
-        // Leave if user canceled device mounting
-        if (!device.mount(true)) {
-          return Device.OPTION_REFRESH_CANCEL;
-        }
-      } catch (final Exception e) {
-        Log.error(11, getName(), e); // mount failed
-        Messages.showErrorMessage(11, getName());
-        throw new JajukException(11);
+      // Leave if user canceled device mounting
+      if (!device.mount(true)) {
+        return Device.OPTION_REFRESH_CANCEL;
       }
     }
     if (bAlreadyRefreshing) {
@@ -626,31 +617,26 @@ public class Device extends PhysicalItem implements Comparable<Device> {
   /**
    * Check that the device is available and not void.
    * 
-   * @param bManual DOCUMENT_ME
+   * @param bManual manual or automatic refresh ?
    * 
-   * @return whether the device is ready for mounting
+   * @return true if the device is ready for mounting, false if the device is void
    * 
-   * @throws JajukException the jajuk exception
+   * @throws JajukException if the device is not accessible
    */
   private boolean checkDevice(boolean bManual) throws JajukException {
-    try {
-      final File file = new File(getUrl());
-      if (!file.exists()) {
-        throw new Exception("Path does not exist: " + file.toString());
-      }
-    } catch (final Exception e) {
-      throw new JajukException(11, getName(), e);
+    final File file = new File(getUrl());
+    if (!file.exists()) {
+      throw new JajukException(11, "\"" + getName() + "\" at URL : " + getUrl());
     }
     /*
-     * Cannot mount void devices because of reference garbager thread ( a refresh would clear the
-     * device)
+     * Cannot mount void devices because of the jajuk reference cleanup thread 
+     * ( a refresh would clear the entire device collection)
      */
-    final File file = new File(getUrl());
-    if ((file.listFiles() == null) || (file.listFiles().length == 0)) {
+    if (file.listFiles() == null || file.listFiles().length == 0) {
       if (bManual) {
-        final int answer = Messages.getChoice("[" + getName() + "] "
-            + Messages.getString("Confirmation_void_refresh"), JOptionPane.YES_NO_CANCEL_OPTION,
-            JOptionPane.WARNING_MESSAGE);
+        final int answer = Messages.getChoice(
+            "[" + getName() + "] " + Messages.getString("Confirmation_void_refresh"),
+            JOptionPane.YES_NO_CANCEL_OPTION, JOptionPane.WARNING_MESSAGE);
         // leave if user doesn't confirm to mount the void device
         return (answer == JOptionPane.YES_OPTION);
       } else {
@@ -670,9 +656,9 @@ public class Device extends PhysicalItem implements Comparable<Device> {
    * 
    * @return whether the device has been mounted
    * 
-   * @throws Exception if device cannot be mounted
+   * @throws JajukException if device cannot be mounted
    */
-  public boolean mount(final boolean bManual) throws Exception {
+  public boolean mount(final boolean bManual) throws JajukException {
     if (bMounted) {
       throw new JajukException(111);
     }
@@ -685,7 +671,6 @@ public class Device extends PhysicalItem implements Comparable<Device> {
     }
     // notify views to refresh if needed
     ObservationManager.notify(new JajukEvent(JajukEvents.DEVICE_MOUNT));
-
     return bMounted;
   }
 
@@ -838,18 +823,6 @@ public class Device extends PhysicalItem implements Comparable<Device> {
         scanRecursively(dir, bDeepScan);
       }
 
-      // Force cover detection (after done once, the cover file is cached as album property)
-      // We need this to avoid bug #1550 : if the device is created, then unplugged, catalog
-      // view cover/no-cover filter is messed-up because the findCover() method always return null.
-      Set<Album> albumsToCheck = getAlbumsForDirectories(dirs);
-      for (Album album : albumsToCheck) {
-        album.findCoverFile();
-        // Give a chance to leave this loop when user required end of session
-        if (ExitService.isExiting()) {
-          break;
-        }
-      }
-
       // Force a GUI refresh if new files or directories discovered or have been
       // removed
       if (((FileManager.getInstance().getElementCount() - iNbFilesBeforeRefresh) != 0)
@@ -878,30 +851,11 @@ public class Device extends PhysicalItem implements Comparable<Device> {
     }
   }
 
-  /**
-   * Return list of albums for a list of directories.
-   * 
-   * @param dirs the directories to extract albums from recursively
-   * 
-   * @return list of albums for a list of directories
-   */
-  private Set<Album> getAlbumsForDirectories(List<Directory> dirs) {
-    Set<Album> out = new HashSet<Album>(dirs.size() * 10);
-    for (Directory dir : dirs) {
-      List<org.jajuk.base.File> files = dir.getFilesRecursively();
-      for (org.jajuk.base.File file : files) {
-        out.add(file.getTrack().getAlbum());
-      }
-    }
-    return out;
-  }
-
   /**
    * Scan recursively.
-   * DOCUMENT_ME
-   * 
-   * @param dir DOCUMENT_ME
-   * @param bDeepScan DOCUMENT_ME
+   *  
+   * @param dir top directory to scan
+   * @param bDeepScan whether we want to perform a deep scan (read tags again)
    */
   private void scanRecursively(final Directory dir, final boolean bDeepScan) {
     dir.scan(bDeepScan, reporter);
@@ -1022,10 +976,10 @@ public class Device extends PhysicalItem implements Comparable<Device> {
       }
       // end message
       lTime = System.currentTimeMillis() - lTime;
-      final String sOut = new StringBuilder(Messages.getString("Device.33")).append(
-          ((lTime < 1000) ? lTime + " ms" : lTime / 1000 + " s")).append(" - ").append(
-          iNbCreatedFilesSrc + iNbCreatedFilesDest).append(Messages.getString("Device.35")).append(
-          lVolume / 1048576).append(Messages.getString("Device.36")).toString();
+      final String sOut = new StringBuilder(Messages.getString("Device.33"))
+          .append(((lTime < 1000) ? lTime + " ms" : lTime / 1000 + " s")).append(" - ")
+          .append(iNbCreatedFilesSrc + iNbCreatedFilesDest).append(Messages.getString("Device.35"))
+          .append(lVolume / 1048576).append(Messages.getString("Device.36")).toString();
       // perform a fast refresh
       refreshCommand(false, true, null);
       // if bidi sync, refresh the other device as well (new file can
@@ -1137,9 +1091,9 @@ public class Device extends PhysicalItem implements Comparable<Device> {
               iNbCreatedFiles++;
               lVolume += element.length();
               InformationJPanel.getInstance().setMessage(
-                  new StringBuilder(Messages.getString("Device.41")).append(dSrc.getName()).append(
-                      ',').append(dest.getName()).append(Messages.getString("Device.42")).append(
-                      element.getAbsolutePath()).append("]").toString(),
+                  new StringBuilder(Messages.getString("Device.41")).append(dSrc.getName())
+                      .append(',').append(dest.getName()).append(Messages.getString("Device.42"))
+                      .append(element.getAbsolutePath()).append("]").toString(),
                   InformationJPanel.MessageType.INFORMATIVE);
             } catch (final JajukException je) {
               Messages.showErrorMessage(je.getCode(), element.getAbsolutePath());
