@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -32,6 +32,7 @@ import javazoom.jlgui.basicplayer.BasicPlayerEvent;
 import javazoom.jlgui.basicplayer.BasicPlayerException;
 import javazoom.jlgui.basicplayer.BasicPlayerListener;
 
+import org.jajuk.services.covers.Cover;
 import org.jajuk.util.UtilFeatures;
 
 /**
@@ -361,4 +362,13 @@ public class NoTagsTagImpl implements ITagImpl {
     return tagFieldKeyArrayList;
   }
 
+  /* (non-Javadoc)
+   * @see org.jajuk.services.tags.ITagImpl#getCovers()
+   */
+  @Override
+  public List<Cover> getCovers() throws Exception {
+    // TODO Auto-generated method stub
+    return null;
+  }
+
 }
