@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -30,6 +30,7 @@ import org.jajuk.base.PropertyMetaInformation;
 import org.jajuk.base.TrackManager;
 import org.jajuk.base.Type;
 import org.jajuk.base.TypeManager;
+import org.jajuk.services.covers.Cover;
 import org.jajuk.ui.widgets.InformationJPanel;
 import org.jajuk.util.Conf;
 import org.jajuk.util.Const;
@@ -161,7 +162,6 @@ public class Tag {
     if (tagImpl == null) {
       return sArtistName;
     }
-
     try {
       String sTemp = tagImpl.getArtistName().trim();
       if (Messages.getString(Const.UNKNOWN_ARTIST).equals(sTemp)) {
@@ -177,7 +177,6 @@ public class Tag {
     }
     // We internalize the artist name for memory saving reasons
     return sArtistName.intern();
-
   }
 
   /**
@@ -384,6 +383,25 @@ public class Tag {
     return sLyrics;
   }
 
+  /**
+   * Gets the embedded covers. 
+   * 
+   * @return the covers or a void list if none.
+   */
+  public List<Cover> getCovers() {
+    List<Cover> covers = new ArrayList<Cover>(1);
+    // if the type doesn't support tags ( like wav )
+    if (tagImpl == null) {
+      return covers;
+    }
+    try {
+      covers = tagImpl.getCovers();
+    } catch (Exception e) {
+      Log.info("Wrong covers:{{" + fio.getName() + "}}");
+    }
+    return covers;
+  }
+
   /**
    * Sets the track name.
    * 
