@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *  $Revision: 6186 $
+ *  $Revision$
  */
 
 package org.jajuk.ui.views;
@@ -29,8 +29,6 @@ import java.awt.event.ActionListener;
 import java.awt.event.ComponentEvent;
 import java.awt.event.ComponentListener;
 import java.awt.event.MouseEvent;
-import java.awt.image.BufferedImage;
-import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.IOException;
@@ -45,7 +43,6 @@ import java.util.List;
 import java.util.Properties;
 import java.util.Set;
 
-import javax.imageio.ImageIO;
 import javax.swing.BorderFactory;
 import javax.swing.ImageIcon;
 import javax.swing.JComboBox;
@@ -71,11 +68,11 @@ import org.jajuk.base.Track;
 import org.jajuk.events.JajukEvent;
 import org.jajuk.events.JajukEvents;
 import org.jajuk.events.ObservationManager;
-import org.jajuk.services.core.SessionService;
 import org.jajuk.services.covers.Cover;
 import org.jajuk.services.covers.Cover.CoverType;
 import org.jajuk.services.players.QueueModel;
 import org.jajuk.services.players.StackItem;
+import org.jajuk.services.tags.Tag;
 import org.jajuk.ui.helpers.JajukMouseAdapter;
 import org.jajuk.ui.thumbnails.ThumbnailManager;
 import org.jajuk.ui.widgets.InformationJPanel;
@@ -99,10 +96,6 @@ import org.jajuk.util.filters.ImageFilter;
 import org.jajuk.util.filters.JPGFilter;
 import org.jajuk.util.filters.PNGFilter;
 import org.jajuk.util.log.Log;
-import org.jaudiotagger.audio.AudioFile;
-import org.jaudiotagger.audio.AudioFileIO;
-import org.jaudiotagger.tag.Tag;
-import org.jaudiotagger.tag.datatype.Artwork;
 
 /**
  * Cover view. Displays an image for the current album
@@ -191,6 +184,28 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
   /** DOCUMENT_ME. */
   private boolean includeControls;
 
+  /** Thread launch at view init to reset its state */
+  private class CoverResetThread extends Thread {
+    @Override
+    public void run() {
+      if (fileReference == null) {
+        if (QueueModel.isStopped()) {
+          update(new JajukEvent(JajukEvents.ZERO));
+        } else {
+          // check if a track has already been launched
+          if (QueueModel.isPlayingRadio()) {
+            update(new JajukEvent(JajukEvents.WEBRADIO_LAUNCHED,
+                ObservationManager.getDetailsLastOccurence(JajukEvents.WEBRADIO_LAUNCHED)));
+          } else {
+            update(new JajukEvent(JajukEvents.FILE_LAUNCHED));
+          }
+        }
+      } else {
+        update(new JajukEvent(JajukEvents.COVER_NEED_REFRESH));
+      }
+    }
+  }
+
   /**
    * Constructor.
    */
@@ -226,8 +241,7 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
    */
   /**
    * Inits the ui.
-   * DOCUMENT_ME
-   * 
+   *  
    * @param includeControls DOCUMENT_ME
    */
   public void initUI(boolean includeControls) {
@@ -348,38 +362,10 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
     setLayout(globalLayout);
     add(jpControl, "grow,wrap");
 
-    // Force initial cover refresh
-    new Thread() {
-      @Override
-      public void run() {
-        // Wait a while to make sure that the view has been fully displayed
-        try {
-          Thread.sleep(2000);
-        } catch (InterruptedException e) {
-          Log.error(e);
-        }
-        if (fileReference == null) {
-          if (QueueModel.isStopped()) {
-            update(new JajukEvent(JajukEvents.ZERO));
-          } else {
-            // check if a track has already been launched
-            if (QueueModel.isPlayingRadio()) {
-              update(new JajukEvent(JajukEvents.WEBRADIO_LAUNCHED, ObservationManager
-                  .getDetailsLastOccurence(JajukEvents.WEBRADIO_LAUNCHED)));
-            } else {
-              update(new JajukEvent(JajukEvents.FILE_LAUNCHED));
-            }
-          }
-        } else {
-          update(new JajukEvent(JajukEvents.COVER_NEED_REFRESH));
-        }
+    // listen for resize. We do it here to avoid a useless resize event at
+    // init and an associated blinking effect
+    addComponentListener(CoverView.this);
 
-        // listen for resize. We do it here to avoid a useless resize event at
-        // init and an associated blinking effect
-        addComponentListener(CoverView.this);
-
-      }
-    }.start();
   }
 
   /*
@@ -415,8 +401,8 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
     // Note that we have to store/retrieve accuracy using an id. When
     // this view is used from a popup, we can't use perspective id
     Conf.setProperty(Const.CONF_COVERS_ACCURACY + "_"
-        + ((getPerspective() == null) ? "popup" : getPerspective().getID()), Integer
-        .toString(jcbAccuracy.getSelectedIndex()));
+        + ((getPerspective() == null) ? "popup" : getPerspective().getID()),
+        Integer.toString(jcbAccuracy.getSelectedIndex()));
 
     new Thread("Cover Accuracy Thread") {
       @Override
@@ -482,10 +468,8 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
 
     // show confirmation message if required
     if (Conf.getBoolean(Const.CONF_CONFIRMATIONS_DELETE_COVER)) {
-      final int iResu = Messages
-          .getChoice(Messages.getString("Confirmation_delete_cover") + " : "
-              + cover.getURL().getFile(), JOptionPane.YES_NO_CANCEL_OPTION,
-              JOptionPane.WARNING_MESSAGE);
+      final int iResu = Messages.getChoice(Messages.getString("Confirmation_delete_cover") + " : "
+          + cover.getFile(), JOptionPane.YES_NO_CANCEL_OPTION, JOptionPane.WARNING_MESSAGE);
       if (iResu != JOptionPane.YES_OPTION) {
         return;
       }
@@ -493,7 +477,7 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
 
     // yet there? ok, delete the cover
     try {
-      final File file = new File(cover.getURL().getFile());
+      final File file = cover.getFile();
       if (file.isFile() && file.exists()) {
         UtilSystem.deleteFile(file);
       } else { // not a file, must have a problem
@@ -550,14 +534,10 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
           Log.debug("Try to save a local cover");
           return;
         }
-
         String sFilePath = null;
-
         sFilePath = dirReference.getFio().getPath() + "/"
             + UtilSystem.getOnlyFile(cover.getURL().toString());
-
-        sFilePath = getCoverFilePath(sFilePath);
-
+        sFilePath = convertCoverPath(sFilePath);
         try {
           // copy file from cache
           final File fSource = DownloadManager.downloadToCache(cover.getURL());
@@ -570,11 +550,11 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
             alCovers.add(cover2);
             setFoundText();
           }
-          // Reset cached cover
-          org.jajuk.base.File fCurrent = fileReference;
-          if (fCurrent == null) {
-            fCurrent = QueueModel.getPlayingFile();
-          }
+
+          // Reset cached cover in associated albums to make sure that new covers
+          // will be discovered in various views like Catalog View.
+          resetCachedCover();
+
           // Notify cover change
           ObservationManager.notify(new JajukEvent(JajukEvents.COVER_NEED_REFRESH));
           // add new cover in others cover views
@@ -587,25 +567,41 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
   }
 
   /**
-   * Gets the cover file path.
-   * 
-   * @param sFilePath DOCUMENT_ME
-   * 
-   * @return the cover file path
+   * Reset cached cover in associated albums to make sure that new covers
+   *  will be discovered in various views like Catalog View.
    */
-  private String getCoverFilePath(String sFilePath) {
+  private void resetCachedCover() {
+    org.jajuk.base.File fCurrent = fileReference;
+    if (fCurrent == null) {
+      fCurrent = QueueModel.getPlayingFile();
+    }
+    Set<Album> albums = fCurrent.getDirectory().getAlbums();
+    // If we cached NO_COVER for this album, make sure to reset this value
+    for (Album album : albums) {
+      String cachedCoverPath = album.getStringValue(XML_ALBUM_DISCOVERED_COVER);
+      if (COVER_NONE.equals(cachedCoverPath)) {
+        album.setProperty(XML_ALBUM_DISCOVERED_COVER, "");
+      }
+      ObservationManager.notify(new JajukEvent(JajukEvents.COVER_DEFAULT_CHANGED));
+    }
+  }
 
+  /**
+   * Converts a cover path according to options and jajuk conventions
+   * 
+   * @param sFilePath current cover path
+   * 
+   * @return the converted cover file path
+   */
+  private String convertCoverPath(String sFilePath) {
     int pos = sFilePath.lastIndexOf('.');
-
     if (Conf.getBoolean(Const.CONF_COVERS_SAVE_EXPLORER_FRIENDLY)) {
-      // covers should be stored as folder.xxx for windows
-      // explorer
+      // Covers should be stored as folder.xxx for windows explorer
       String ext = sFilePath.substring(pos, sFilePath.length());
       String parent = new File(sFilePath).getParent();
       return parent + System.getProperty("file.separator") + "Folder" + ext;
     } else {
-      // Add a jajuk suffix to know this cover has been downloaded
-      // by jajuk
+      // Add a jajuk suffix to know this cover has been downloaded by jajuk
       return new StringBuilder(sFilePath).insert(pos, Const.FILE_JAJUK_DOWNLOADED_FILES_SUFFIX)
           .toString();
     }
@@ -629,8 +625,8 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
       @Override
       public void run() {
         final Cover cover = alCovers.get(index);
-        final JajukFileChooser jfchooser = new JajukFileChooser(new JajukFileFilter(GIFFilter
-            .getInstance(), PNGFilter.getInstance(), JPGFilter.getInstance()));
+        final JajukFileChooser jfchooser = new JajukFileChooser(new JajukFileFilter(
+            GIFFilter.getInstance(), PNGFilter.getInstance(), JPGFilter.getInstance()));
         jfchooser.setAcceptDirectories(true);
         jfchooser.setCurrentDirectory(dirReference.getFio());
         jfchooser.setDialogTitle(Messages.getString("CoverView.10"));
@@ -649,11 +645,11 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
             UtilSystem.copy(cover.getFile(), fNew);
             InformationJPanel.getInstance().setMessage(Messages.getString("CoverView.11"),
                 InformationJPanel.MessageType.INFORMATIVE);
-            // Reset cached cover
-            org.jajuk.base.File fCurrent = fileReference;
-            if (fCurrent == null) {
-              fCurrent = QueueModel.getPlayingFile();
-            }
+
+            // Reset cached cover in associated albums to make sure that new covers
+            // will be discovered in various views like Catalog View.
+            resetCachedCover();
+
             // Notify cover change
             ObservationManager.notify(new JajukEvent(JajukEvents.COVER_NEED_REFRESH));
           } catch (final Exception ex) {
@@ -678,84 +674,70 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
       Log.warn("Cannot default cover with invalid index.");
       return;
     }
-
-    // choose a default
-    // first commit this cover on the disk if it is a remote cover
-    org.jajuk.base.File fCurrent = fileReference;
-    if (fCurrent == null) {
-      fCurrent = QueueModel.getPlayingFile();
-    }
-    final Cover cover = alCovers.get(index);
-
-    if (cover.getType() == CoverType.TAG_COVER) {
-      String sFilePath = getCoverFilePath(dirReference.getFio().getPath() + "/"
-          + cover.getFile().getName());
-      File destFile = new File(sFilePath);
-      try {
-        // copy file
-        UtilSystem.copy(cover.getFile(), destFile);
-        alCovers.add(new Cover(destFile, CoverType.SELECTED_COVER));
-        ThumbnailManager.cleanThumbs(fCurrent.getTrack().getAlbum());
-        refreshThumbs(cover);
-        InformationJPanel.getInstance().setMessage(Messages.getString("CoverView.11"),
-            InformationJPanel.MessageType.INFORMATIVE);
-
-        // set default
-        fCurrent.getTrack().getAlbum().setProperty(XML_ALBUM_COVER, destFile.getAbsolutePath());
-
-        ObservationManager.notify(new JajukEvent(JajukEvents.COVER_DEFAULT_CHANGED));
-        ObservationManager.notify(new JajukEvent(JajukEvents.COVER_NEED_REFRESH));
-
-        return;
-      } catch (JajukException e) {
-        Log.error(e);
-      } catch (IOException e) {
-        Log.error(e);
-      }
-    } else if (cover.getType() == CoverType.REMOTE_COVER) {
-      final String sFilename = UtilSystem.getOnlyFile(cover.getURL().toString());
-      String sFilePath = dirReference.getFio().getPath() + "/" + sFilename;
-
-      sFilePath = getCoverFilePath(sFilePath);
-      try {
-        // copy file from cache
-        final File fSource = DownloadManager.downloadToCache(cover.getURL());
-        final File file = new File(sFilePath);
-        UtilSystem.copy(fSource, file);
-        final Cover cover2 = new Cover(file, CoverType.SELECTED_COVER);
-        if (!alCovers.contains(cover2)) {
-          alCovers.add(cover2);
-          setFoundText();
+    new Thread("Default cover thread") {
+      public void run() {
+        Cover cover = alCovers.get(index);
+        org.jajuk.base.File fCurrent = fileReference;
+        // Path of the default cover, it is simply the URL of the current cover for local covers
+        // but it is another path to a newly created image for tag or remote covers
+        String destPath = cover.getFile().getAbsolutePath();
+        if (fCurrent == null) {
+          fCurrent = QueueModel.getPlayingFile();
+        }
+        if (cover.getType() == CoverType.TAG_COVER) {
+          destPath = dirReference.getFio().getPath() + "/" + cover.getFile().getName();
+          destPath = convertCoverPath(destPath);
+          File destFile = new File(destPath);
+          try {
+            // Copy cached file to music directory
+            // Note that the refreshCover() methods automatically 
+            // extract any track cover tag to an image file in the cache
+            UtilSystem.copy(cover.getFile(), destFile);
+            Cover cover2 = new Cover(destFile, CoverType.SELECTED_COVER);
+            alCovers.add(cover2);
+          } catch (Exception ex) {
+            Log.error(24, ex);
+            Messages.showErrorMessage(24);
+            return;
+          }
+        } else if (cover.getType() == CoverType.REMOTE_COVER) {
+          String sFilename = UtilSystem.getOnlyFile(cover.getURL().toString());
+          destPath = dirReference.getFio().getPath() + "/" + sFilename;
+          destPath = convertCoverPath(destPath);
+          try {
+            // Download cover and copy file from cache to music directory
+            File fSource = DownloadManager.downloadToCache(cover.getURL());
+            File fileDest = new File(destPath);
+            UtilSystem.copy(fSource, new File(destPath));
+            Cover cover2 = new Cover(fileDest, CoverType.SELECTED_COVER);
+            if (!alCovers.contains(cover2)) {
+              alCovers.add(cover2);
+              setFoundText();
+            }
+          } catch (Exception ex) {
+            Log.error(24, ex);
+            Messages.showErrorMessage(24);
+            return;
+          }
         }
         // Remove previous thumbs to avoid using outdated images
         // Reset cached cover
         ThumbnailManager.cleanThumbs(fCurrent.getTrack().getAlbum());
-        // fCurrent.getTrack().getAlbum().setProperty(XML_ALBUM_COVER, null);
         refreshThumbs(cover);
-        InformationJPanel.getInstance().setMessage(Messages.getString("CoverView.11"),
+        InformationJPanel.getInstance().setMessage(Messages.getString("Success"),
             InformationJPanel.MessageType.INFORMATIVE);
-      } catch (final IOException ex) {
-        Log.error(24, ex);
-        Messages.showErrorMessage(24);
-      } catch (final JajukException ex) {
-        Log.error(24, ex);
-        Messages.showErrorMessage(24);
-      } catch (final RuntimeException ex) {
-        Log.error(24, ex);
-        Messages.showErrorMessage(24);
+        // For every kind of cover types :
+        ObservationManager.notify(new JajukEvent(JajukEvents.COVER_DEFAULT_CHANGED));
+        ObservationManager.notify(new JajukEvent(JajukEvents.COVER_NEED_REFRESH));
+        // then make it the default cover for this album
+        if (fCurrent != null && fCurrent.getTrack() != null
+            && fCurrent.getTrack().getAlbum() != null && cover.getFile() != null) {
+          Album album = fCurrent.getTrack().getAlbum();
+          album.setProperty(XML_ALBUM_SELECTED_COVER, destPath);
+          album.setProperty(XML_ALBUM_DISCOVERED_COVER, destPath);
+        }
       }
-    } else {
-      refreshThumbs(cover);
-      InformationJPanel.getInstance().setMessage(Messages.getString("Success"),
-          InformationJPanel.MessageType.INFORMATIVE);
-    }
-    ObservationManager.notify(new JajukEvent(JajukEvents.COVER_DEFAULT_CHANGED));
-    // then make it the default cover for this album
-    if (fCurrent != null && fCurrent.getTrack() != null && fCurrent.getTrack().getAlbum() != null
-        && cover.getFile() != null) {
-      fCurrent.getTrack().getAlbum()
-          .setProperty(XML_ALBUM_COVER, cover.getFile().getAbsolutePath());
-    }
+    }.start();
   }
 
   /*
@@ -773,7 +755,11 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
       return;
     }
     lDateLastResize = lCurrentDate;
-    displayCurrentCover();
+    // Force initial cover refresh. We do this inside this method and not initUI() 
+    // because we make sure that the window is fully displayed then (otherwise, we get 
+    // a black cover when switching from slimbar to main window for ie)
+    CoverResetThread refresh = new CoverResetThread();
+    refresh.start();
   }
 
   /**
@@ -798,38 +784,38 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
     final Album album = track.getAlbum();
     switch (iAccuracy) {
     case 0: // low, default
-      if (!artist.isUnknown()) {
+      if (!artist.seemsUnknown()) {
         sQuery += artist.getName() + " ";
       }
-      if (!album.isUnknown()) {
+      if (!album.seemsUnknown()) {
         sQuery += album.getName() + " ";
       }
       break;
     case 1: // medium
-      if (!artist.isUnknown()) {
+      if (!artist.seemsUnknown()) {
         sQuery += '\"' + artist.getName() + QUOTE_BLANK;
         // put quotes around it
       }
-      if (!album.isUnknown()) {
+      if (!album.seemsUnknown()) {
         sQuery += '\"' + album.getName() + QUOTE_BLANK;
       }
       break;
     case 2: // high
-      if (!artist.isUnknown()) {
+      if (!artist.seemsUnknown()) {
         sQuery += PLUS_QUOTE + artist.getName() + QUOTE_BLANK;
         // put "" around it
       }
-      if (!album.isUnknown()) {
+      if (!album.seemsUnknown()) {
         sQuery += PLUS_QUOTE + album.getName() + QUOTE_BLANK;
       }
       break;
     case 3: // by artist
-      if (!artist.isUnknown()) {
+      if (!artist.seemsUnknown()) {
         sQuery += artist.getName() + " ";
       }
       break;
     case 4: // by album
-      if (!album.isUnknown()) {
+      if (!album.seemsUnknown()) {
         sQuery += album.getName() + " ";
       }
       break;
@@ -857,12 +843,13 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
     final Cover cover = alCovers.get(index); // take image at the given index
     final URL url = cover.getURL();
     // enable delete button only for local covers
-    if (cover.getType() == CoverType.LOCAL_COVER || cover.getType() == CoverType.SELECTED_COVER
-        || cover.getType() == CoverType.STANDARD_COVER) {
-      jbDelete.setEnabled(true);
-    } else {
-      jbDelete.setEnabled(false);
-    }
+    jbDelete.setEnabled(cover.getType() == CoverType.LOCAL_COVER
+        || cover.getType() == CoverType.SELECTED_COVER
+        || cover.getType() == CoverType.STANDARD_COVER);
+
+    //Disable default command for "none" cover
+    jbDefault.setEnabled(cover.getType() != CoverType.NO_COVER);
+
     if (url != null) {
       jbSave.setEnabled(false);
       String sType = " (L)"; // local cover
@@ -1165,7 +1152,6 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
       Log.warn("Cannot refresh thumbnails without reference directory");
       return;
     }
-
     // refresh thumbs
     try {
       for (int size = 50; size <= 300; size += 50) {
@@ -1401,7 +1387,6 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
   private void refreshCovers(int iLocalEventID, boolean dirChanged) throws IOException {
     // Reset this flag
     bForceCoverReload = false;
-
     org.jajuk.base.File fCurrent = fileReference;
     // check if a file has been given for this cover view
     // if not, take current cover
@@ -1415,7 +1400,6 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
       // store this dir
       dirReference = fCurrent.getDirectory();
     }
-
     if (dirReference == null) {
       alCovers.clear();
       alCovers.add(CoverView.nocover);
@@ -1429,24 +1413,36 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
           + "variable fCurrent should not be empty. dirReference: " + dirReference);
     }
 
-    // we only need to refresh the other covers if the directory changed, save cpu
+    // We only need to refresh the other covers if the directory changed 
+    // but we still clear tag-based covers even if directory didn't change
+    // so the song-specific tag is token into account. 
+    Iterator<Cover> it = alCovers.iterator();
+    while (it.hasNext()) {
+      Cover cover = it.next();
+      if (cover.getType() == CoverType.TAG_COVER) {
+        it.remove();
+      }
+    }
     if (dirChanged) {
       // remove all existing covers
       alCovers.clear();
 
-      // search for local covers in all directories mapping
+      // Search for local covers in all directories mapping
       // the current track to reach other devices covers and
       // display them together
       final Track trackCurrent = fCurrent.getTrack();
       final List<org.jajuk.base.File> alFiles = trackCurrent.getFiles();
 
-      // Add any absolute default cover
-      String defaultCoverPath = trackCurrent.getAlbum().getStringValue(XML_ALBUM_COVER);
+      // Add any selected default cover
+      String defaultCoverPath = trackCurrent.getAlbum().getStringValue(XML_ALBUM_SELECTED_COVER);
       if (StringUtils.isNotBlank(defaultCoverPath)) {
         File coverFile = new File(defaultCoverPath);
         if (coverFile.exists()) {
           final Cover cover = new Cover(coverFile, CoverType.SELECTED_COVER);
-          alCovers.add(cover);
+          // Avoid dups
+          if (!alCovers.contains(cover)) {
+            alCovers.add(cover);
+          }
         }
       }
 
@@ -1457,7 +1453,7 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
           // if the device is not ready, just ignore it
           continue;
         }
-        // Now search for regular local covers
+        // Now search for regular or standard local covers
         // null if none file found
         final java.io.File[] files = dirScanned.getFio().listFiles();
         for (int i = 0; (files != null) && (i < files.length); i++) {
@@ -1543,44 +1539,20 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
       }
     }
 
-    // if the last file had a tag cover, we must remove it
-    // we can not use the cover type because a tag cover could be set as default.
-    if (!dirChanged) {
-      Cover coverToRemove = null;
-      for (Cover c : alCovers) {
-        if (c.getFile().getName().equalsIgnoreCase(Const.TAG_COVER_FILE)
-            || c.getType().equals(CoverType.NO_COVER)) {
-          coverToRemove = c;
-          break;
-        }
-      }
-      if (coverToRemove != null)
-        alCovers.remove(coverToRemove);
-    }
-
-    // check if a cover is stored in the file
+    // Check for tag covers 
     try {
-      AudioFile f = AudioFileIO.read(fCurrent.getFIO());
-      Tag tag = f.getTag();
-      if (tag != null) {
-        Artwork artwork = tag.getFirstArtwork();
-        byte[] imageRawData = artwork != null ? artwork.getBinaryData() : null;
-
-        if (imageRawData != null) {
-          BufferedImage bi = ImageIO.read(new ByteArrayInputStream(imageRawData));
-          if (bi != null) {
-            File coverFile = SessionService.getConfFileByPath(Const.FILE_CACHE + '/'
-                + Const.TAG_COVER_FILE);
-            ImageIO.write(bi, "png", coverFile);
-            Cover cover = new Cover(coverFile, CoverType.TAG_COVER);
-            alCovers.addLast(cover);
-          }
-
+      Tag tag = new Tag(fCurrent.getFIO(), false);
+      List<Cover> tagCovers = tag.getCovers();
+      // Reverse order of the found tag covers because we want best last
+      // in alCovers and we want to keep tag order.
+      Collections.reverse(tagCovers);
+      for (Cover cover : tagCovers) {
+        // Avoid dups
+        if (!alCovers.contains(cover)) {
+          alCovers.add(cover);
         }
-
       }
-    } catch (Exception e1) {
-      // current file is not supported by jaudiotagger
+    } catch (JajukException e1) {
       Log.error(e1);
     }
 
@@ -1601,4 +1573,4 @@ public class CoverView extends ViewAdapter implements ComponentListener, ActionL
     }
     displayCurrentCover();
   }
-}
\ No newline at end of file
+}
