@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -567,6 +567,7 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
       new Thread("Parameter Catalog refresh Thread") {
         @Override
         public void run() {
+          UtilGUI.waiting();
           // Force albums to search for new covers
           AlbumManager.getInstance().resetCoverCache();
           // Clean thumbs
@@ -576,6 +577,7 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
           ThumbnailManager.cleanThumbs(THUMBNAIL_SIZE_200X200);
           ThumbnailManager.cleanThumbs(THUMBNAIL_SIZE_250X250);
           ThumbnailManager.cleanThumbs(THUMBNAIL_SIZE_300X300);
+          UtilGUI.stopWaiting();
           // For catalog view's update
           ObservationManager.notify(new JajukEvent(JajukEvents.DEVICE_REFRESH));
           // Display a message
@@ -592,29 +594,28 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
   private void applyParameters() {
     // **Read all parameters**
     // Options
-    Conf.setProperty(Const.CONF_OPTIONS_HIDE_UNMOUNTED, Boolean.toString(jcbDisplayUnmounted
-        .isSelected()));
-    Conf.setProperty(Const.CONF_OPTIONS_PUSH_ON_CLICK, Boolean.toString(jcbDefaultActionClick
-        .isSelected()));
-    Conf.setProperty(Const.CONF_OPTIONS_PUSH_ON_DROP, Boolean.toString(jcbDefaultActionDrop
-        .isSelected()));
+    Conf.setProperty(Const.CONF_OPTIONS_HIDE_UNMOUNTED,
+        Boolean.toString(jcbDisplayUnmounted.isSelected()));
+    Conf.setProperty(Const.CONF_OPTIONS_PUSH_ON_CLICK,
+        Boolean.toString(jcbDefaultActionClick.isSelected()));
+    Conf.setProperty(Const.CONF_OPTIONS_PUSH_ON_DROP,
+        Boolean.toString(jcbDefaultActionDrop.isSelected()));
     Conf.setProperty(Const.CONF_OPTIONS_HOTKEYS, Boolean.toString(jcbHotkeys.isSelected()));
-    Conf.setProperty(Const.CONF_LASTFM_AUDIOSCROBBLER_ENABLE, Boolean.toString(jcbAudioScrobbler
-        .isSelected()));
-    Conf.setProperty(Const.CONF_LASTFM_INFO, Boolean.toString(jcbEnableLastFMInformation
-        .isSelected()));
+    Conf.setProperty(Const.CONF_LASTFM_AUDIOSCROBBLER_ENABLE,
+        Boolean.toString(jcbAudioScrobbler.isSelected()));
+    Conf.setProperty(Const.CONF_LASTFM_INFO,
+        Boolean.toString(jcbEnableLastFMInformation.isSelected()));
     Conf.setProperty(Const.CONF_LASTFM_USER, jtfASUser.getText());
-    Conf.setProperty(Const.CONF_LASTFM_PASSWORD, UtilString.rot13(new String(jpfASPassword
-        .getPassword())));
+    Conf.setProperty(Const.CONF_LASTFM_PASSWORD,
+        UtilString.rot13(new String(jpfASPassword.getPassword())));
     final int iLogLevel = scbLogLevel.getSelectedIndex();
     Log.setVerbosity(iLogLevel);
     Conf.setProperty(Const.CONF_OPTIONS_LOG_LEVEL, Integer.toString(iLogLevel));
     Conf.setProperty(Const.CONF_OPTIONS_INTRO_BEGIN, Integer.toString(introPosition.getValue()));
     Conf.setProperty(Const.CONF_OPTIONS_INTRO_LENGTH, Integer.toString(introLength.getValue()));
-    Conf
-        .setProperty(Const.CONF_TAGS_USE_PARENT_DIR, Boolean.toString(jcbUseParentDir.isSelected()));
-    Conf.setProperty(Const.CONF_DROP_PLAYED_TRACKS_FROM_QUEUE, Boolean
-        .toString(jcbDropPlayedTracksFromQueue.isSelected()));
+    Conf.setProperty(Const.CONF_TAGS_USE_PARENT_DIR, Boolean.toString(jcbUseParentDir.isSelected()));
+    Conf.setProperty(Const.CONF_DROP_PLAYED_TRACKS_FROM_QUEUE,
+        Boolean.toString(jcbDropPlayedTracksFromQueue.isSelected()));
     final String sBestofSize = jtfBestofSize.getText();
     if (!sBestofSize.isEmpty()) {
       Conf.setProperty(Const.CONF_BESTOF_TRACKS_SIZE, sBestofSize);
@@ -659,17 +660,17 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
       Conf.setProperty(Const.CONF_STARTUP_MODE, Const.STARTUP_MODE_NOVELTIES);
     }
     // Confirmations
-    Conf.setProperty(Const.CONF_CONFIRMATIONS_DELETE_FILE, Boolean.toString(jcbBeforeDelete
-        .isSelected()));
+    Conf.setProperty(Const.CONF_CONFIRMATIONS_DELETE_FILE,
+        Boolean.toString(jcbBeforeDelete.isSelected()));
     Conf.setProperty(Const.CONF_CONFIRMATIONS_EXIT, Boolean.toString(jcbBeforeExit.isSelected()));
-    Conf.setProperty(Const.CONF_CONFIRMATIONS_REMOVE_DEVICE, Boolean.toString(jcbBeforeRemoveDevice
-        .isSelected()));
-    Conf.setProperty(Const.CONF_CONFIRMATIONS_DELETE_COVER, Boolean.toString(jcbBeforeDeleteCover
-        .isSelected()));
-    Conf.setProperty(Const.CONF_CONFIRMATIONS_CLEAR_HISTORY, Boolean
-        .toString(jcbBeforeClearingHistory.isSelected()));
-    Conf.setProperty(Const.CONF_CONFIRMATIONS_RESET_RATINGS, Boolean
-        .toString(jcbBeforeResetingRatings.isSelected()));
+    Conf.setProperty(Const.CONF_CONFIRMATIONS_REMOVE_DEVICE,
+        Boolean.toString(jcbBeforeRemoveDevice.isSelected()));
+    Conf.setProperty(Const.CONF_CONFIRMATIONS_DELETE_COVER,
+        Boolean.toString(jcbBeforeDeleteCover.isSelected()));
+    Conf.setProperty(Const.CONF_CONFIRMATIONS_CLEAR_HISTORY,
+        Boolean.toString(jcbBeforeClearingHistory.isSelected()));
+    Conf.setProperty(Const.CONF_CONFIRMATIONS_RESET_RATINGS,
+        Boolean.toString(jcbBeforeResetingRatings.isSelected()));
     // History
     final String sHistoryDuration = jtfHistory.getText();
     if (!sHistoryDuration.isEmpty()) {
@@ -733,8 +734,8 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
     if (oldPerspectiveSize != jsPerspectiveSize.getValue()) {
       someOptionsAppliedAtNextStartup = true;
     }
-    Conf.setProperty(Const.CONF_PERSPECTIVE_ICONS_SIZE, Integer.toString(jsPerspectiveSize
-        .getValue()));
+    Conf.setProperty(Const.CONF_PERSPECTIVE_ICONS_SIZE,
+        Integer.toString(jsPerspectiveSize.getValue()));
     // LAF change
     final String oldTheme = Conf.getString(Const.CONF_OPTIONS_LNF);
     Conf.setProperty(Const.CONF_OPTIONS_LNF, (String) scbLAF.getSelectedItem());
@@ -816,8 +817,8 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
     }
 
     // Network
-    Conf.setProperty(Const.CONF_NETWORK_NONE_INTERNET_ACCESS, Boolean
-        .toString(jcbNoneInternetAccess.isSelected()));
+    Conf.setProperty(Const.CONF_NETWORK_NONE_INTERNET_ACCESS,
+        Boolean.toString(jcbNoneInternetAccess.isSelected()));
     Conf.setProperty(Const.CONF_NETWORK_USE_PROXY, Boolean.toString(!jcbProxyNone.isSelected()));
     if (jcbProxyHttp.isSelected()) {
       Conf.setProperty(Const.CONF_NETWORK_PROXY_TYPE, Const.PROXY_TYPE_HTTP);
@@ -827,8 +828,8 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
     Conf.setProperty(Const.CONF_NETWORK_PROXY_HOSTNAME, jtfProxyHostname.getText());
     Conf.setProperty(Const.CONF_NETWORK_PROXY_PORT, jtfProxyPort.getText());
     Conf.setProperty(Const.CONF_NETWORK_PROXY_LOGIN, jtfProxyLogin.getText());
-    Conf.setProperty(Const.CONF_NETWORK_PROXY_PWD, UtilString.rot13(new String(jtfProxyPwd
-        .getPassword())));
+    Conf.setProperty(Const.CONF_NETWORK_PROXY_PWD,
+        UtilString.rot13(new String(jtfProxyPwd.getPassword())));
     Conf.setProperty(Const.CONF_NETWORK_CONNECTION_TO, Integer.toString(connectionTO.getValue()));
     // Force global reload of proxy variables
     DownloadManager.setDefaultProxySettings();
@@ -837,8 +838,8 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
     ObservationManager.notify(new JajukEvent(JajukEvents.COVER_NEED_REFRESH));
     Conf.setProperty(Const.CONF_COVERS_AUTO_COVER, Boolean.toString(jcbAutoCover.isSelected()));
     Conf.setProperty(Const.CONF_COVERS_SHUFFLE, Boolean.toString(jcbShuffleCover.isSelected()));
-    Conf.setProperty(Const.CONF_COVERS_SAVE_EXPLORER_FRIENDLY, Boolean
-        .toString(jcbSaveExplorerFriendly.isSelected()));
+    Conf.setProperty(Const.CONF_COVERS_SAVE_EXPLORER_FRIENDLY,
+        Boolean.toString(jcbSaveExplorerFriendly.isSelected()));
     Conf.setProperty(Const.CONF_COVERS_SIZE, Integer.toString(jcbCoverSize.getSelectedIndex()));
     Conf.setProperty(Const.FILE_DEFAULT_COVER, jtfDefaultCoverSearchPattern.getText());
 
@@ -892,8 +893,8 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
       public void actionPerformed(ActionEvent e) {
         // Store configuration
         Conf.setProperty(Const.CONF_SHOW_POPUPS, Boolean.toString(jcbShowPopups.isSelected()));
-        Conf.setProperty(Const.CONF_NETWORK_NONE_INTERNET_ACCESS, Boolean
-            .toString(jcbNoneInternetAccess.isSelected()));
+        Conf.setProperty(Const.CONF_NETWORK_NONE_INTERNET_ACCESS,
+            Boolean.toString(jcbNoneInternetAccess.isSelected()));
         // Launch an event that can be trapped by the tray to
         // synchronize the state
         Properties details = new Properties();
@@ -931,18 +932,18 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
       }
     });
     jtfHistory.setToolTipText(Messages.getString("ParameterView.2"));
-    jbClearHistory = new JButton(Messages.getString("ParameterView.3"), IconLoader
-        .getIcon(JajukIcons.CLEAR));
+    jbClearHistory = new JButton(Messages.getString("ParameterView.3"),
+        IconLoader.getIcon(JajukIcons.CLEAR));
     jbClearHistory.setToolTipText(Messages.getString("ParameterView.4"));
     jbClearHistory.addActionListener(this);
 
-    jbResetRatings = new JButton(Messages.getString("ParameterView.186"), IconLoader
-        .getIcon(JajukIcons.CLEAR));
+    jbResetRatings = new JButton(Messages.getString("ParameterView.186"),
+        IconLoader.getIcon(JajukIcons.CLEAR));
     jbResetRatings.setToolTipText(Messages.getString("ParameterView.187"));
     jbResetRatings.addActionListener(this);
 
-    jbResetPreferences = new JButton(Messages.getString("ParameterView.249"), IconLoader
-        .getIcon(JajukIcons.CLEAR));
+    jbResetPreferences = new JButton(Messages.getString("ParameterView.249"),
+        IconLoader.getIcon(JajukIcons.CLEAR));
     jbResetPreferences.setToolTipText(Messages.getString("ParameterView.250"));
     jbResetPreferences.addActionListener(this);
 
@@ -1000,29 +1001,6 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
     };
     // disabled by default, is enabled only if jrbFile is enabled
     sbSearch.setEnabled(false);
-    // set chosen track in file selection
-    String conf = Conf.getString(Const.CONF_STARTUP_ITEM);
-    String item = conf.substring(conf.indexOf('/') + 1, conf.length());
-    if (!StringUtils.isBlank(item)) {
-      if (conf.matches(SearchResultType.FILE.name() + ".*")) {
-        File file = FileManager.getInstance().getFileByID(item);
-        if (file != null) {
-          sbSearch.setText(file.getTrack().getName());
-        } else {
-          // the file exists no more, remove its id as startup file
-          Conf.setProperty(Const.CONF_STARTUP_ITEM, "");
-        }
-      } else if (conf.matches(SearchResultType.WEBRADIO.name() + ".*")) {
-        WebRadio radio = WebRadioManager.getInstance().getWebRadioByName(item);
-        if (radio != null) {
-          sbSearch.setText(radio.getName());
-        } else {
-          // the file exists no more, remove its id as startup file
-          Conf.setProperty(Const.CONF_STARTUP_ITEM, "");
-        }
-      }
-    }
-
     sbSearch.setToolTipText(Messages.getString("ParameterView.18"));
     bgStart.add(jrbNothing);
     bgStart.add(jrbLast);
@@ -1189,7 +1167,6 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
     crossFadeDuration.setToolTipText(Messages.getString("ParameterView.191"));
     crossFadeDuration.addMouseWheelListener(new DefaultMouseWheelListener(crossFadeDuration));
     jcbUseVolnorm = new JCheckBox(Messages.getString("ParameterView.262"));
-    jcbUseVolnorm.setSelected(Conf.getBoolean(Const.CONF_USE_VOLNORM));
     jcbUseVolnorm.setToolTipText(Messages.getString("ParameterView.263"));
 
     // add panels
@@ -1530,7 +1507,7 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
     jcbSaveExplorerFriendly.addActionListener(this);
 
     // Add items
-    jpCovers = new JPanel(new MigLayout("insets 10,gapy 15,gapx 10"));
+    jpCovers = new JPanel(new MigLayout("insets 10,gapy 15,gapx 10", "[40%][40%]"));
     jpCovers.add(jcbShuffleCover, "wrap");
     jpCovers.add(jcbAutoCover, "wrap");
     jpCovers.add(jcb3dCover, "wrap");
@@ -1584,8 +1561,8 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
     jsPerspectiveSize.setPaintTicks(true);
     jsPerspectiveSize.setPaintLabels(true);
     jsPerspectiveSize.setToolTipText(Messages.getString("ParameterView.246"));
-    jbCatalogRefresh = new JajukButton(Messages.getString("CatalogView.19"), IconLoader
-        .getIcon(JajukIcons.REFRESH));
+    jbCatalogRefresh = new JajukButton(Messages.getString("CatalogView.19"),
+        IconLoader.getIcon(JajukIcons.REFRESH));
     jbCatalogRefresh.setToolTipText(Messages.getString("CatalogView.3"));
     jbCatalogRefresh.addActionListener(this);
     final JXCollapsiblePane catalogView = new JXCollapsiblePane();
@@ -1653,8 +1630,8 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
     // --OK/cancel panel
     jbOK = new JButton(Messages.getString("ParameterView.85"), IconLoader.getIcon(JajukIcons.OK));
     jbOK.addActionListener(this);
-    jbDefault = new JButton(Messages.getString("ParameterView.86"), IconLoader
-        .getIcon(JajukIcons.DEFAULTS_BIG));
+    jbDefault = new JButton(Messages.getString("ParameterView.86"),
+        IconLoader.getIcon(JajukIcons.DEFAULTS_BIG));
     jbDefault.addActionListener(this);
 
     // --Global layout
@@ -1764,6 +1741,30 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
     } else if (Conf.getString(Const.CONF_STARTUP_MODE).equals(Const.STARTUP_MODE_NOVELTIES)) {
       jrbNovelties.setSelected(true);
     }
+    // set chosen track in file selection
+    String conf = Conf.getString(Const.CONF_STARTUP_ITEM);
+    String item = conf.substring(conf.indexOf('/') + 1, conf.length());
+    if (!StringUtils.isBlank(item)) {
+      if (conf.matches(SearchResultType.FILE.name() + ".*")) {
+        File file = FileManager.getInstance().getFileByID(item);
+        if (file != null) {
+          sbSearch.setText(file.getTrack().getName());
+        } else {
+          // the file exists no more, remove its id as startup file
+          Conf.setProperty(Const.CONF_STARTUP_ITEM, "");
+        }
+      } else if (conf.matches(SearchResultType.WEBRADIO.name() + ".*")) {
+        WebRadio radio = WebRadioManager.getInstance().getWebRadioByName(item);
+        if (radio != null) {
+          sbSearch.setText(radio.getName());
+        } else {
+          // the file exists no more, remove its id as startup file
+          Conf.setProperty(Const.CONF_STARTUP_ITEM, "");
+        }
+      }
+    } else {
+      sbSearch.setText("");
+    }
     // Confirmations
     jcbBeforeDelete.setSelected(Conf.getBoolean(Const.CONF_CONFIRMATIONS_DELETE_FILE));
     jcbBeforeExit.setSelected(Conf.getBoolean(Const.CONF_CONFIRMATIONS_EXIT));
@@ -1800,6 +1801,7 @@ public class ParameterView extends ViewAdapter implements ActionListener, ItemLi
     jcbUseParentDir.setSelected(Conf.getBoolean(Const.CONF_TAGS_USE_PARENT_DIR));
     jcbDropPlayedTracksFromQueue.setSelected(Conf
         .getBoolean(Const.CONF_DROP_PLAYED_TRACKS_FROM_QUEUE));
+    jcbUseVolnorm.setSelected(Conf.getBoolean(Const.CONF_USE_VOLNORM));
     // advanced
     final int iBackupSize = Conf.getInt(Const.CONF_BACKUP_SIZE);
     if (iBackupSize <= 0) { // backup size =0 means no backup
