@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *  $Revision: 6186 $
+ *  $Revision$
  */
 
 package org.jajuk.ui.wizard;
@@ -68,6 +68,7 @@ import org.jajuk.base.TrackManager;
 import org.jajuk.events.JajukEvent;
 import org.jajuk.events.JajukEvents;
 import org.jajuk.events.ObservationManager;
+import org.jajuk.ui.widgets.CopyableLabel;
 import org.jajuk.ui.widgets.InformationJPanel;
 import org.jajuk.ui.widgets.JajukJDialog;
 import org.jajuk.ui.widgets.OKCancelPanel;
@@ -241,6 +242,7 @@ public class PropertiesDialog extends JajukJDialog implements ActionListener {
    */
   private void display() {
     SwingUtilities.invokeLater(new Runnable() {
+      @Override
       public void run() {
         // If none editable item, save button is disabled
         if (iEditable == 0) {
@@ -260,6 +262,7 @@ public class PropertiesDialog extends JajukJDialog implements ActionListener {
    * 
    * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
    */
+  @Override
   public void actionPerformed(ActionEvent e) {
     if (e.getSource() == okc.getCancelButton()) {
       dispose();
@@ -421,6 +424,7 @@ public class PropertiesDialog extends JajukJDialog implements ActionListener {
           if (meta.getType().equals(Date.class)) {
             final JXDatePicker jdp = new JXDatePicker();
             jdp.addActionListener(new ActionListener() {
+              @Override
               public void actionPerformed(ActionEvent arg0) {
                 Object oValue = jdp.getDate();
                 hmPropertyToChange.put(meta, oValue);
@@ -440,6 +444,7 @@ public class PropertiesDialog extends JajukJDialog implements ActionListener {
             // for a boolean, value is a checkbox
             final JCheckBox jcb = new JCheckBox();
             jcb.addActionListener(new ActionListener() {
+              @Override
               public void actionPerformed(ActionEvent arg0) {
                 Object oValue = jcb.isSelected();
                 hmPropertyToChange.put(meta, oValue);
@@ -517,6 +522,7 @@ public class PropertiesDialog extends JajukJDialog implements ActionListener {
               jcb.setSelectedIndex(-1);
             }
             jcb.addActionListener(new ActionListener() {
+              @Override
               public void actionPerformed(ActionEvent arg0) {
                 Object oValue = jcb.getSelectedItem();
                 if (oValue == null || ((String) oValue).trim().length() == 0) {
@@ -567,6 +573,7 @@ public class PropertiesDialog extends JajukJDialog implements ActionListener {
               jcb.setSelectedIndex(-1);
             }
             jcb.addActionListener(new ActionListener() {
+              @Override
               public void actionPerformed(ActionEvent arg0) {
                 Object oValue = jcb.getSelectedItem();
                 if (oValue == null || ((String) oValue).trim().length() == 0) {
@@ -600,13 +607,13 @@ public class PropertiesDialog extends JajukJDialog implements ActionListener {
             widgets[index][1] = jtfValue;
           }
         } else {
-          JLabel jl = null;
+          CopyableLabel jl = null;
           if (meta.getName().equals(Const.XML_ALBUM_DISC_ID)) {
             // Specific rendering : the album disc id should be translated from decimal to hex
-            jl = new JLabel((Long.toString(((Long) pa.getValue(meta.getName())), 16)));
+            jl = new CopyableLabel((Long.toString(((Long) pa.getValue(meta.getName())), 16)));
           } else {
             // Regular un-editable item rendering
-            jl = new JLabel(pa.getHumanValue(meta.getName()));
+            jl = new CopyableLabel(pa.getHumanValue(meta.getName()));
           }
           // If several items, take first value found
           if (bAllEquals) {
@@ -680,6 +687,7 @@ public class PropertiesDialog extends JajukJDialog implements ActionListener {
      * 
      * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
      */
+    @Override
     public void actionPerformed(ActionEvent ae) {
       // Link
       if (ae.getActionCommand().equals("link")) {
