@@ -1,6 +1,6 @@
 /*
  *  Jajuk
- *  Copyright (C) 2003-2010 The Jajuk Team
+ *  Copyright (C) 2003-2011 The Jajuk Team
  *  http://jajuk.info
  *
  *  This program is free software; you can redistribute it and/or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- *  $Revision: 6186 $
+ *  $Revision$
  */
 package org.jajuk.util;
 
@@ -42,6 +42,9 @@ public interface Const {
   /** Time we wait after an error in ms. */
   int WAIT_AFTER_ERROR = 2000;
 
+  /** We need a fix size to have the same angle effect for every cover*/
+  int MIRROW_COVER_SIZE = 600;
+
   /** Default playlist name. */
   String DEFAULT_PLAYLIST_FILE = "playlist";
 
@@ -101,6 +104,9 @@ public interface Const {
 
   /** Number of pixels around window at initial startup. */
   int FRAME_INITIAL_BORDER = 60;
+  
+  /** Maximum images cache size in MB */
+  int MAX_IMAGES_CACHE_SIZE = 100;
 
   /** Default webradio. */
   String DEFAULT_WEBRADIO = "Bluemars [Ambient/Space-Music]";
@@ -153,7 +159,7 @@ public interface Const {
   long MPLAYER_OSX_EXE_SIZE = 21490476l;
 
   /** Update URL = PAD file URL. */
-  String CHECK_FOR_UPDATE_URL = "http://jajuk.svn.sourceforge.net/svnroot/jajuk/trunk/jajuk/src/site/resources/jajuk_pad.xml";
+  String CHECK_FOR_UPDATE_URL = "http://gitorious.org/jajuk/jajuk/blobs/raw/master/jajuk/src/packaging/pad/jajuk_pad.xml";
 
   // Jajuk version
   /** DOCUMENT_ME. */
@@ -169,7 +175,7 @@ public interface Const {
   String JAJUK_VERSION_DATE = "Build: DATE_REPLACED_BY_ANT";
 
   /** DOCUMENT_ME. */
-  String JAJUK_COPYRIGHT = "Copyright 2003-2010 The Jajuk Team";
+  String JAJUK_COPYRIGHT = "Copyright 2003-2011 The Jajuk Team";
 
   /** DOCUMENT_ME. */
   String TYPE_VIDEO = "Type.video";
@@ -221,9 +227,9 @@ public interface Const {
   /** DOCUMENT_ME. */
   URL FILE_LOG4J_CONF = UtilSystem.getResource("org/jajuk/util/log/jajuk-log4j-conf.xml");
 
-  /** DOCUMENT_ME. */
+  /** Cache directory name. */
   String FILE_CACHE = "cache";
-
+ 
   /** Bat Converter to DOS 8.3 format */
   String FILE_FILENAME_CONVERTER = "converter.bat";
 
@@ -1178,9 +1184,12 @@ public interface Const {
   /** DOCUMENT_ME. */
   String XML_EXPANDED = "exp"; // can be 'y' or 'n'
 
-  /** DOCUMENT_ME. */
-  String XML_ALBUM_COVER = "cover";
-
+  /** Cached cover. */
+  String XML_ALBUM_DISCOVERED_COVER = "cover_cache";
+  
+  /** Selected cover. */
+  String XML_ALBUM_SELECTED_COVER = "cover";
+  
   /** DOCUMENT_ME. */
   String XML_DIRECTORY_PARENT = "parent";
 
@@ -1469,4 +1478,4 @@ public interface Const {
   /** File name where the tag cover is stored in. */
   String TAG_COVER_FILE = "tag_cover.png";
 
-}
\ No newline at end of file
+}
